# Usage: perl ima2matrix.pl
#
# Transforms all data in files with .ima extentions (ISGI formatted files)
# in the current directory into a single numeric-only file named
# data_cat.matrix with format
#
# Column 1   = MOYR (e.g., 12004 = January, 2004)
# Column 2   = CODE (18=aa, 2=am)
# Column 3   = Number of days in month
# Column 4   = Ave in 1st 3-hour interval of month
# ...
# Column 248 = Ave in 248th( = 8*31) 3-hour interval of month
#
# If month has less than 31 days, -1 is used as fill so that each line
# has 248 columns.
#  
# R.S. Weigel 04/07/2004.

$DATA_OUT = 'data_cat.matrix';
open(DATA_out,">$DATA_OUT");

$dirname = './';

opendir(DIR, $dirname) or die "can't opendir $dirname: $!";

while (defined($file = readdir(DIR))) {
    if ($file =~ /\.ima/) {

	open(DATA_in,"$file");
	print "ima2matrix.pl is operating on file: $file ... ";

	while ( $line1 = <DATA_in> ){
	    chomp($line1);
	    $line2 = <DATA_in> ; chomp($line2);
	    $line3 = <DATA_in> ; chomp($line3);
	    $line4 = <DATA_in> ; chomp($line4);
	    $line5 = <DATA_in> ; chomp($line5);
	    $line6 = <DATA_in> ; chomp($line6);
	    $line7 = <DATA_in> ; chomp($line7);
	    $line8 = <DATA_in> ; chomp($line8);
	    $line9 = <DATA_in> ; chomp($line9);
	    
	    $line_cat = $line1 . $line2 . $line3 . $line4 .
		        $line5 . $line6 . $line7 . $line8 . $line9;

            # Some aa files use unix newline (\n), 
	    # others use windows style newline (\r\n).
	    # chomp only removes newline of local OS.
	    # So here we remove any end-of-line character for

	    # Windows
	    $line_cat =~ s/\cM//g; 
	    # Linux
	    $line_cat =~ s/\cJ//g; 

            print(DATA_out "$line_cat\n");
	}

	close(INFILE);
	print "Done.\n";
    }
}
print "Output file is data_cat.matrix\n";
close(DATA_out);
